==> haskell-tar-conduit-0.4.1-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-1J8Evaib7x18jpBSa0jZxp
key:                  tar-conduit-0.4.1-1J8Evaib7x18jpBSa0jZxp
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  41f78ea3a8c6f48e49409b3faecc72cd
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-1J8Evaib7x18jpBSa0jZxp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-JOByYHd4UhSLHkAURX473h containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-exceptions-0.1.7.4-9jJG7wIPjIM4P97UFwsUXF text-2.0.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.4.1-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-BzRl0eP1Cn23qVN8pSFlhK
key:                  tar-conduit-0.4.1-BzRl0eP1Cn23qVN8pSFlhK
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  efdfdc2c7406666a3bed11e7e696b061
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-BzRl0eP1Cn23qVN8pSFlhK
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-8EwOhhDv3r5EX0bCaWMPRW containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-exceptions-0.1.7.4-2w96WaZrQg3AekPG2bQV4R text-2.0.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
